==> dashvector-1.0.5-py3-none-any.whl: dashvector/core/models/delete_partition_request.py <==
##
#   Copyright 2021 Alibaba, Inc. and its affiliates. All Rights Reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
##

# -*- coding: utf-8 -*-

import re

from dashvector.common.constants import *
from dashvector.common.error import DashVectorCode, DashVectorException
from dashvector.common.handler import RPCRequest
from dashvector.core.proto import dashvector_pb2


class DeletePartitionRequest(RPCRequest):

    def __init__(self, *,
                 collection_name: str,
                 partition_name: str):
        """
        collection_name: str
        """
        self._collection_name = collection_name

        """
        partition_name: str
        """
        self._partition_name = partition_name

        if not isinstance(partition_name, str):
            raise DashVectorException(
                code=DashVectorCode.InvalidArgument,
                reason=f"DashVectorSDK DropPartitionRequest name type({partition_name}) is invalid and must be str")

        if re.search(
                COLLECTION_AND_PARTITION_NAME_PATTERN,
                partition_name) is None:
            raise DashVectorException(
                code=DashVectorCode.InvalidPartitionName,
                reason=f"DashVectorSDK DropPartitionRequest name characters({partition_name}) is invalid and " +
                COLLECTION_AND_PARTITION_NAME_PATTERN_MSG)
        self._partition_name = partition_name

        """
        DropPartitionRequest: google.protobuf.Message
        """
        drop_request = dashvector_pb2.DeletePartitionRequest(
            name=self._partition_name)

        super().__init__(request=drop_request)

    @property
    def collection_name(self):
        return self._collection_name

    @property
    def partition_name(self):
        return self._partition_name

==> dashvector-1.0.6-py3-none-any.whl: dashvector/core/models/delete_partition_request.py <==
##
#   Copyright 2021 Alibaba, Inc. and its affiliates. All Rights Reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
##

# -*- coding: utf-8 -*-

import re

from dashvector.common.constants import *
from dashvector.common.error import DashVectorCode, DashVectorException
from dashvector.common.handler import RPCRequest
from dashvector.core.proto import dashvector_pb2


class DeletePartitionRequest(RPCRequest):
    def __init__(self, *, collection_name: str, partition_name: str):
        """
        collection_name: str
        """
        self._collection_name = collection_name

        """
        partition_name: str
        """
        self._partition_name = partition_name

        if not isinstance(partition_name, str):
            raise DashVectorException(
                code=DashVectorCode.InvalidArgument,
                reason=f"DashVectorSDK DropPartitionRequest name type({partition_name}) is invalid and must be str",
            )

        if re.search(COLLECTION_AND_PARTITION_NAME_PATTERN, partition_name) is None:
            raise DashVectorException(
                code=DashVectorCode.InvalidPartitionName,
                reason=f"DashVectorSDK DropPartitionRequest name characters({partition_name}) is invalid and "
                + COLLECTION_AND_PARTITION_NAME_PATTERN_MSG,
            )
        self._partition_name = partition_name

        """
        DropPartitionRequest: google.protobuf.Message
        """
        drop_request = dashvector_pb2.DeletePartitionRequest(name=self._partition_name)

        super().__init__(request=drop_request)

    @property
    def collection_name(self):
        return self._collection_name

    @property
    def partition_name(self):
        return self._partition_name
